# DRF Json Api Utils

Utilities to reduce the boiler-plating of [django-rest-framework-json-api][drfjapi].

[The source for this project is available here][src].

Example Usuage
----

```python

```


[src]: https://github.com/amitassaraf/drf-json-api-utils
[drfjapi]: https://github.com/django-json-api/django-rest-framework-json-api